@@ -1,6 +1,5 @@
 // -*- mode: cpp; mode: fold -*-
 // Description								/*{{{*/
-// $Id: acquire.cc,v 1.50 2004/03/17 05:17:11 mdz Exp $
 /* ######################################################################
 
    Acquire - File Acquiration
@@ -24,6 +23,7 @@
 #include <apt-pkg/strutl.h>
 
 #include <algorithm>
+#include <chrono>
 #include <iomanip>
 #include <iostream>
 #include <memory>
@@ -127,25 +127,6 @@ static bool SetupAPTPartialDirectory(std::string const &grand, std::string const
 
    return true;
 }
-bool pkgAcquire::Setup(pkgAcquireStatus *Progress, string const &Lock)
-{
-   Log = Progress;
-   if (Lock.empty())
-   {
-      string const listDir = _config->FindDir("Dir::State::lists");
-      if (SetupAPTPartialDirectory(_config->FindDir("Dir::State"), listDir, "partial", 0700) == false)
-	 return _error->Errno("Acquire", _("List directory %s is missing."), (listDir + "partial").c_str());
-      if (SetupAPTPartialDirectory(_config->FindDir("Dir::State"), listDir, "auxfiles", 0755) == false)
-      {
-	 // not being able to create lists/auxfiles isn't critical as we will use a tmpdir then
-      }
-      string const archivesDir = _config->FindDir("Dir::Cache::Archives");
-      if (SetupAPTPartialDirectory(_config->FindDir("Dir::Cache"), archivesDir, "partial", 0700) == false)
-	 return _error->Errno("Acquire", _("Archives directory %s is missing."), (archivesDir + "partial").c_str());
-      return true;
-   }
-   return GetLock(Lock);
-}
 bool pkgAcquire::GetLock(std::string const &Lock)
 {
    if (Lock.empty() == true)
@@ -415,6 +396,7 @@ string pkgAcquire::QueueName(string Uri,MethodConfig const *&Config)
    if (Config->SingleInstance == true || QueueMode == QueueAccess)
       return U.Access;
 
+   int Limit = 10;
    string AccessSchema = U.Access + ':';
    string FullQueueName;
 
@@ -433,15 +415,15 @@ string pkgAcquire::QueueName(string Uri,MethodConfig const *&Config)
 #ifdef _SC_NPROCESSORS_ONLN
       long cpuCount = sysconf(_SC_NPROCESSORS_ONLN) * 2;
 #else
-      long cpuCount = 10;
+      long cpuCount = Limit;
 #endif
-      cpuCount = _config->FindI("Acquire::QueueHost::Limit", cpuCount);
+      Limit = _config->FindI("Acquire::QueueHost::Limit", cpuCount);
 
-      if (cpuCount <= 0 || existing < cpuCount)
+      if (Limit <= 0 || existing < Limit)
 	 strprintf(FullQueueName, "%s%ld", AccessSchema.c_str(), existing);
       else
       {
-	 long const randomQueue = random() % cpuCount;
+	 long const randomQueue = random() % Limit;
 	 strprintf(FullQueueName, "%s%ld", AccessSchema.c_str(), randomQueue);
       }
 
@@ -449,6 +431,7 @@ string pkgAcquire::QueueName(string Uri,MethodConfig const *&Config)
          clog << "Chose random queue " << FullQueueName << " for " << Uri << endl;
    } else
    {
+      Limit = _config->FindI("Acquire::QueueHost::Limit", Limit);
       FullQueueName = AccessSchema + U.Host;
    }
    unsigned int Instances = 0, SchemaLength = AccessSchema.length();
@@ -467,7 +450,7 @@ string pkgAcquire::QueueName(string Uri,MethodConfig const *&Config)
       clog << "Found " << Instances << " instances of " << U.Access << endl;
    }
 
-   if (Instances >= static_cast<decltype(Instances)>(_config->FindI("Acquire::QueueHost::Limit",10)))
+   if (Instances >= static_cast<decltype(Instances)>(Limit))
       return U.Access;
 
    return FullQueueName;
@@ -654,7 +637,7 @@ static void CheckDropPrivsMustBeDisabled(pkgAcquire const &Fetcher)
 
       // if its the source file (e.g. local sources) we might be lucky
       // by dropping the dropping only for some methods.
-      URI const source = (*I)->DescURI();
+      URI const source((*I)->DescURI());
       if (source.Access == "file" || source.Access == "copy")
       {
 	 std::string const conf = "Binary::" + source.Access + "::APT::Sandbox::User";
@@ -1257,6 +1240,13 @@ pkgAcquireStatus::pkgAcquireStatus() : d(NULL), Percent(-1), Update(true), MoreP
 /* This computes some internal state variables for the derived classes to
    use. It generates the current downloaded bytes and total bytes to download
    as well as the current CPS estimate. */
+static struct timeval GetTimevalFromSteadyClock()
+{
+   auto const Time = std::chrono::steady_clock::now().time_since_epoch();
+   auto const Time_sec = std::chrono::duration_cast<std::chrono::seconds>(Time);
+   auto const Time_usec = std::chrono::duration_cast<std::chrono::microseconds>(Time - Time_sec);
+   return { Time_sec.count(), Time_usec.count() };
+}
 bool pkgAcquireStatus::Pulse(pkgAcquire *Owner)
 {
    TotalBytes = 0;
@@ -1294,13 +1284,13 @@ bool pkgAcquireStatus::Pulse(pkgAcquire *Owner)
    {
       if (I->CurrentItem != 0 && I->CurrentItem->Owner->Complete == false)
       {
-	 CurrentBytes += I->CurrentSize;
-	 ResumeSize += I->ResumePoint;
+	 CurrentBytes += I->CurrentItem->CurrentSize;
+	 ResumeSize += I->CurrentItem->ResumePoint;
 
 	 // Files with unknown size always have 100% completion
 	 if (I->CurrentItem->Owner->FileSize == 0 &&
 	     I->CurrentItem->Owner->Complete == false)
-	    TotalBytes += I->CurrentSize;
+	    TotalBytes += I->CurrentItem->CurrentSize;
       }
    }
    
@@ -1315,21 +1305,22 @@ bool pkgAcquireStatus::Pulse(pkgAcquire *Owner)
       CurrentBytes = TotalBytes;
 
    // Compute the CPS
-   struct timeval NewTime;
-   gettimeofday(&NewTime,0);
+   struct timeval NewTime = GetTimevalFromSteadyClock();
+
    if ((NewTime.tv_sec - Time.tv_sec == 6 && NewTime.tv_usec > Time.tv_usec) ||
        NewTime.tv_sec - Time.tv_sec > 6)
-   {    
-      double Delta = NewTime.tv_sec - Time.tv_sec + 
-	             (NewTime.tv_usec - Time.tv_usec)/1000000.0;
-      
+   {
+      std::chrono::duration<double> Delta =
+	 std::chrono::seconds(NewTime.tv_sec - Time.tv_sec) +
+	 std::chrono::microseconds(NewTime.tv_usec - Time.tv_usec);
+
       // Compute the CPS value
-      if (Delta < 0.01)
+      if (Delta < std::chrono::milliseconds(10))
 	 CurrentCPS = 0;
       else
-	 CurrentCPS = ((CurrentBytes - ResumeSize) - LastBytes)/Delta;
+	 CurrentCPS = ((CurrentBytes - ResumeSize) - LastBytes)/ Delta.count();
       LastBytes = CurrentBytes - ResumeSize;
-      ElapsedTime = std::llround(Delta);
+      ElapsedTime = llround(Delta.count());
       Time = NewTime;
    }
 
@@ -1361,21 +1352,21 @@ bool pkgAcquireStatus::Pulse(pkgAcquire *Owner)
       return true;
 
    int fd = _config->FindI("APT::Status-Fd",-1);
-   if(fd > 0) 
+   if(fd > 0)
    {
       ostringstream status;
 
-      char msg[200];
-      long i = CurrentItems < TotalItems ? CurrentItems + 1 : CurrentItems;
       unsigned long long ETA = 0;
-      if(CurrentCPS > 0)
+      if(CurrentCPS > 0 && TotalBytes > CurrentBytes)
          ETA = (TotalBytes - CurrentBytes) / CurrentCPS;
 
+      std::string msg;
+      long i = CurrentItems < TotalItems ? CurrentItems + 1 : CurrentItems;
       // only show the ETA if it makes sense
-      if (ETA > 0 && ETA < 172800 /* two days */ )
-	 snprintf(msg,sizeof(msg), _("Retrieving file %li of %li (%s remaining)"), i, TotalItems, TimeToStr(ETA).c_str());
+      if (ETA > 0 && ETA < std::chrono::seconds(std::chrono::hours(24 * 2)).count())
+	 strprintf(msg, _("Retrieving file %li of %li (%s remaining)"), i, TotalItems, TimeToStr(ETA).c_str());
       else
-	 snprintf(msg,sizeof(msg), _("Retrieving file %li of %li"), i, TotalItems);
+	 strprintf(msg, _("Retrieving file %li of %li"), i, TotalItems);
 
       // build the status str
       std::ostringstream str;
@@ -1394,8 +1385,7 @@ bool pkgAcquireStatus::Pulse(pkgAcquire *Owner)
 /* We just reset the counters */
 void pkgAcquireStatus::Start()
 {
-   gettimeofday(&Time,0);
-   gettimeofday(&StartTime,0);
+   Time = StartTime = GetTimevalFromSteadyClock();
    LastBytes = 0;
    CurrentCPS = 0;
    CurrentBytes = 0;
@@ -1412,19 +1402,19 @@ void pkgAcquireStatus::Start()
 void pkgAcquireStatus::Stop()
 {
    // Compute the CPS and elapsed time
-   struct timeval NewTime;
-   gettimeofday(&NewTime,0);
-   
-   double Delta = NewTime.tv_sec - StartTime.tv_sec + 
-                  (NewTime.tv_usec - StartTime.tv_usec)/1000000.0;
-   
+   struct timeval NewTime = GetTimevalFromSteadyClock();
+
+   std::chrono::duration<double> Delta =
+      std::chrono::seconds(NewTime.tv_sec - StartTime.tv_sec) +
+      std::chrono::microseconds(NewTime.tv_usec - StartTime.tv_usec);
+
    // Compute the CPS value
-   if (Delta < 0.01)
+   if (Delta < std::chrono::milliseconds(10))
       CurrentCPS = 0;
    else
-      CurrentCPS = FetchedBytes/Delta;
+      CurrentCPS = FetchedBytes / Delta.count();
    LastBytes = CurrentBytes;
-   ElapsedTime = std::llround(Delta);
+   ElapsedTime = llround(Delta.count());
 }
 									/*}}}*/
 // AcquireStatus::Fetched - Called when a byte set has been fetched	/*{{{*/
@@ -1437,9 +1427,8 @@ void pkgAcquireStatus::Fetched(unsigned long long Size,unsigned long long Resume
 									/*}}}*/
 bool pkgAcquireStatus::ReleaseInfoChanges(metaIndex const * const LastRelease, metaIndex const * const CurrentRelease, std::vector<ReleaseInfoChange> &&Changes)/*{{{*/
 {
-   auto const virt = dynamic_cast<pkgAcquireStatus2*>(this);
-   if (virt != nullptr)
-      return virt->ReleaseInfoChanges(LastRelease, CurrentRelease, std::move(Changes));
+   (void) LastRelease;
+   (void) CurrentRelease;
    return ReleaseInfoChangesAsGlobalErrors(std::move(Changes));
 }
 									/*}}}*/
@@ -1457,12 +1446,6 @@ bool pkgAcquireStatus::ReleaseInfoChangesAsGlobalErrors(std::vector<ReleaseInfoC
    return AllOkay;
 }
 									/*}}}*/
-bool pkgAcquireStatus2::ReleaseInfoChanges(metaIndex const * const, metaIndex const * const, std::vector<ReleaseInfoChange> &&Changes)
-{
-   return ReleaseInfoChangesAsGlobalErrors(std::move(Changes));
-}
-pkgAcquireStatus2::pkgAcquireStatus2() : pkgAcquireStatus() {}
-pkgAcquireStatus2::~pkgAcquireStatus2() {}
 
 
 pkgAcquire::UriIterator::UriIterator(pkgAcquire::Queue *Q) : d(NULL), CurQ(Q), CurItem(0)
