@@ -57,7 +57,7 @@ pkgCache::Header::Header()
 
    /* Whenever the structures change the major version should be bumped,
       whenever the generator changes the minor version should be bumped. */
-   APT_HEADER_SET(MajorVersion, 13);
+   APT_HEADER_SET(MajorVersion, 16);
    APT_HEADER_SET(MinorVersion, 0);
    APT_HEADER_SET(Dirty, false);
 
@@ -125,7 +125,6 @@ bool pkgCache::Header::CheckSizes(Header &Against) const
 // Cache::pkgCache - Constructor					/*{{{*/
 // ---------------------------------------------------------------------
 /* */
-APT_IGNORE_DEPRECATED_PUSH
 pkgCache::pkgCache(MMap *Map, bool DoMap) : Map(*Map), VS(nullptr), d(NULL)
 {
    // call getArchitectures() with cached=false to ensure that the 
@@ -135,7 +134,6 @@ pkgCache::pkgCache(MMap *Map, bool DoMap) : Map(*Map), VS(nullptr), d(NULL)
    if (DoMap == true)
       ReMap();
 }
-APT_IGNORE_DEPRECATED_POP
 									/*}}}*/
 // Cache::ReMap - Reopen the cache file					/*{{{*/
 // ---------------------------------------------------------------------
@@ -215,21 +213,6 @@ map_id_t pkgCache::sHash(StringView Str) const
       Hash = 33 * Hash + tolower_ascii_unsafe(*I);
    return Hash % HeaderP->GetHashTableSize();
 }
-map_id_t pkgCache::sHash(const string &Str) const
-{
-   uint32_t Hash = 5381;
-   for (string::const_iterator I = Str.begin(); I != Str.end(); ++I)
-      Hash = 33 * Hash + tolower_ascii_unsafe((signed char)*I);
-   return Hash % HeaderP->GetHashTableSize();
-}
-
-map_id_t pkgCache::sHash(const char *Str) const
-{
-   uint32_t Hash = 5381;
-   for (const char *I = Str; *I != 0; ++I)
-      Hash = 33 * Hash + tolower_ascii_unsafe((signed char)*I);
-   return Hash % HeaderP->GetHashTableSize();
-}
 
 #if defined(HAVE_FMV_SSE42_AND_CRC32)
 
@@ -307,10 +290,6 @@ uint32_t pkgCache::CacheHash()
 // Cache::FindPkg - Locate a package by name				/*{{{*/
 // ---------------------------------------------------------------------
 /* Returns 0 on error, pointer to the package otherwise */
-pkgCache::PkgIterator pkgCache::FindPkg(const string &Name) {
-   return FindPkg(StringView(Name));
-}
-
 pkgCache::PkgIterator pkgCache::FindPkg(StringView Name) {
 	auto const found = Name.rfind(':');
 	if (found == string::npos)
@@ -327,10 +306,6 @@ pkgCache::PkgIterator pkgCache::FindPkg(StringView Name) {
 // Cache::FindPkg - Locate a package by name				/*{{{*/
 // ---------------------------------------------------------------------
 /* Returns 0 on error, pointer to the package otherwise */
-pkgCache::PkgIterator pkgCache::FindPkg(const string &Name, string const &Arch) {
-   return FindPkg(StringView(Name), StringView(Arch));
-}
-
 pkgCache::PkgIterator pkgCache::FindPkg(StringView Name, StringView Arch) {
 	/* We make a detour via the GrpIterator here as
 	   on a multi-arch environment a group is easier to
@@ -345,10 +320,6 @@ pkgCache::PkgIterator pkgCache::FindPkg(StringView Name, StringView Arch) {
 // Cache::FindGrp - Locate a group by name				/*{{{*/
 // ---------------------------------------------------------------------
 /* Returns End-Pointer on error, pointer to the group otherwise */
-pkgCache::GrpIterator pkgCache::FindGrp(const string &Name) {
-   return FindGrp(StringView(Name));
-}
-
 pkgCache::GrpIterator pkgCache::FindGrp(StringView Name) {
 	if (unlikely(Name.empty() == true))
 		return GrpIterator(*this,0);
@@ -418,12 +389,6 @@ const char *pkgCache::Priority(unsigned char Prio)
 // GrpIterator::FindPkg - Locate a package by arch			/*{{{*/
 // ---------------------------------------------------------------------
 /* Returns an End-Pointer on error, pointer to the package otherwise */
-pkgCache::PkgIterator pkgCache::GrpIterator::FindPkg(string Arch) const {
-   return FindPkg(StringView(Arch));
-}
-pkgCache::PkgIterator pkgCache::GrpIterator::FindPkg(const char *Arch) const {
-   return FindPkg(StringView(Arch));
-}
 pkgCache::PkgIterator pkgCache::GrpIterator::FindPkg(StringView Arch) const {
 	if (unlikely(IsGood() == false || S->FirstPackage == 0))
 		return PkgIterator(*Owner, 0);
@@ -562,19 +527,6 @@ pkgCache::PkgIterator::OkState pkgCache::PkgIterator::State() const
    return NeedsNothing;
 }
 									/*}}}*/
-// PkgIterator::CandVersion - Returns the candidate version string	/*{{{*/
-// ---------------------------------------------------------------------
-/* Return string representing of the candidate version. */
-const char *
-pkgCache::PkgIterator::CandVersion() const
-{
-  //TargetVer is empty, so don't use it.
-  VerIterator version = pkgPolicy(Owner).GetCandidateVer(*this);
-  if (version.IsGood())
-    return version.VerStr();
-  return 0;
-}
-									/*}}}*/
 // PkgIterator::CurVersion - Returns the current version string		/*{{{*/
 // ---------------------------------------------------------------------
 /* Return string representing of the current version. */
@@ -600,15 +552,10 @@ operator<<(std::ostream& out, pkgCache::PkgIterator Pkg)
       return out << "invalid package";
 
    string current = string(Pkg.CurVersion() == 0 ? "none" : Pkg.CurVersion());
-APT_IGNORE_DEPRECATED_PUSH
-   string candidate = string(Pkg.CandVersion() == 0 ? "none" : Pkg.CandVersion());
-APT_IGNORE_DEPRECATED_POP
    string newest = string(Pkg.VersionList().end() ? "none" : Pkg.VersionList().VerStr());
 
    out << Pkg.Name() << " [ " << Pkg.Arch() << " ] < " << current;
-   if (current != candidate)
-      out << " -> " << candidate;
-   if ( newest != "none" && candidate != newest)
+   if ( newest != "none")
       out << " | " << newest;
    if (Pkg->VersionList == 0)
       out << " > ( none )";
@@ -1009,16 +956,6 @@ const char * pkgCache::VerIterator::MultiArchType() const
    return "none";
 }
 									/*}}}*/
-// RlsFileIterator::IsOk - Checks if the cache is in sync with the file	/*{{{*/
-// ---------------------------------------------------------------------
-/* This stats the file and compares its stats with the ones that were
-   stored during generation. Date checks should probably also be
-   included here. */
-bool pkgCache::RlsFileIterator::IsOk()
-{
-   return true;
-}
-									/*}}}*/
 // RlsFileIterator::RelStr - Return the release string			/*{{{*/
 string pkgCache::RlsFileIterator::RelStr()
 {
@@ -1036,16 +973,6 @@ string pkgCache::RlsFileIterator::RelStr()
    return Res;
 }
 									/*}}}*/
-// PkgFileIterator::IsOk - Checks if the cache is in sync with the file	/*{{{*/
-// ---------------------------------------------------------------------
-/* This stats the file and compares its stats with the ones that were
-   stored during generation. Date checks should probably also be
-   included here. */
-bool pkgCache::PkgFileIterator::IsOk()
-{
-   return true;
-}
-									/*}}}*/
 string pkgCache::PkgFileIterator::RelStr()				/*{{{*/
 {
    std::string Res;
