@@ -571,8 +571,8 @@ bool pkgSourceList::AddVolatileFile(std::string const &File, std::vector<std::st
    else if (ext == "changes")
    {
       debDscRecordParser changes(File, nullptr);
-      std::vector<pkgSrcRecords::File2> fileslst;
-      if (changes.Files2(fileslst) == false || fileslst.empty())
+      std::vector<pkgSrcRecords::File> fileslst;
+      if (changes.Files(fileslst) == false || fileslst.empty())
 	 return false;
       auto const basedir = flNotFile(File);
       for (auto && file: fileslst)
@@ -622,22 +622,5 @@ void pkgSourceList::AddVolatileFiles(CommandLine &CmdL, std::vector<std::string>
       }
       return false;
    });
-}
-void pkgSourceList::AddVolatileFiles(CommandLine &CmdL, std::vector<const char*> * const VolatileCmdL)
-{
-   std::remove_if(CmdL.FileList + 1, CmdL.FileList + 1 + CmdL.FileSize(), [&](char const * const I) {
-      if (I != nullptr && (I[0] == '/' || (I[0] == '.' && (I[1] == '\0' || (I[1] == '.' && (I[2] == '\0' || I[2] == '/')) || I[1] == '/'))))
-      {
-	 if (AddVolatileFile(I))
-	 {
-	    if (VolatileCmdL != nullptr)
-	       VolatileCmdL->push_back(I);
-	 }
-	 else
-	    _error->Error(_("Unsupported file %s given on commandline"), I);
-	 return true;
-      }
-      return false;
-   });
 }
 									/*}}}*/
