@@ -31,14 +31,6 @@
 #include <string>
 #include <vector>
 
-#ifndef APT_8_CLEANER_HEADERS
-#include <apt-pkg/tagfile.h>
-#endif
-#ifndef APT_8_CLEANER_HEADERS
-#include <apt-pkg/metaindex.h>
-using std::string;
-using std::vector;
-#endif
 
 class FileFd;
 class pkgTagSection;
@@ -131,7 +123,6 @@ class pkgSourceList
    void AddVolatileFile(pkgIndexFile * const File);
    bool AddVolatileFile(std::string const &File);
    bool AddVolatileFile(std::string const &File, std::vector<std::string> * const VolatileCmdL);
-   APT_DEPRECATED_MSG("Use the overload with string-vector") void AddVolatileFiles(CommandLine &CmdL, std::vector<const char*> * const VolatileCmdL);
    void AddVolatileFiles(CommandLine &CmdL, std::vector<std::string> * const VolatileCmdL);
 
    /** @return list of files registered with #AddVolatileFile */
