@@ -29,6 +29,7 @@
 #include <apt-private/private-source.h>
 
 #include <apt-pkg/debindexfile.h>
+#include <apt-pkg/deblistparser.h>
 
 #include <stddef.h>
 #include <stdio.h>
@@ -208,12 +209,7 @@ static pkgSrcRecords::Parser *FindSrc(const char *Name,
 	 // or RelTag
 	 if (Cache.BuildPolicy() == false)
 	    return nullptr;
-	 pkgPolicy * Policy = dynamic_cast<pkgPolicy*>(Cache.GetPolicy());
-	 if (Policy == nullptr)
-	 {
-	    _error->Fatal("Implementation error: dynamic up-casting policy engine failed in FindSrc!");
-	    return nullptr;
-	 }
+	 pkgPolicy * const Policy = Cache.GetPolicy();
 	 pkgCache::VerIterator const Ver = Policy->GetCandidateVer(Pkg);
 	 if (Ver.end() == false)
 	 {
@@ -388,14 +384,14 @@ bool DoSource(CommandLine &CmdL)
       }
 
       // Back track
-      std::vector<pkgSrcRecords::File2> Lst;
-      if (Last->Files2(Lst) == false) {
+      std::vector<pkgSrcRecords::File> Lst;
+      if (Last->Files(Lst) == false) {
 	 return false;
       }
 
       DscFile curDsc;
       // Load them into the fetcher
-      for (std::vector<pkgSrcRecords::File2>::const_iterator I = Lst.begin();
+      for (std::vector<pkgSrcRecords::File>::const_iterator I = Lst.begin();
 	    I != Lst.end(); ++I)
       {
 	 // Try to guess what sort of file it is we are getting.
@@ -641,15 +637,6 @@ static void WriteBuildDependencyPackage(std::ostringstream &buildDepsPkgFile,
 }
 bool DoBuildDep(CommandLine &CmdL)
 {
-   CacheFile Cache;
-   std::vector<std::string> VolatileCmdL;
-   Cache.GetSourceList()->AddVolatileFiles(CmdL, &VolatileCmdL);
-
-   _config->Set("APT::Install-Recommends", false);
-
-   if (CmdL.FileSize() <= 1 && VolatileCmdL.empty())
-      return _error->Error(_("Must specify at least one package to check builddeps for"));
-
    bool StripMultiArch;
    std::string hostArch = _config->Find("APT::Get::Host-Architecture");
    if (hostArch.empty() == false)
@@ -661,10 +648,23 @@ bool DoBuildDep(CommandLine &CmdL)
    }
    else
       StripMultiArch = true;
+   auto const nativeArch = _config->Find("APT::Architecture");
+   std::string const pseudoArch = hostArch.empty() ? nativeArch : hostArch;
+
+   CacheFile Cache;
+   auto VolatileCmdL = GetPseudoPackages(Cache.GetSourceList(), CmdL, AddVolatileSourceFile, pseudoArch);
+   auto AreDoingSatisfy = strcasecmp(CmdL.FileList[0], "satisfy") == 0;
+
+   if (not AreDoingSatisfy)
+      _config->Set("APT::Install-Recommends", false);
+
+   if (CmdL.FileSize() <= 1 && VolatileCmdL.empty())
+      return _error->Error(_("Must specify at least one package to check builddeps for"));
 
    std::ostringstream buildDepsPkgFile;
-   std::vector<std::pair<std::string,std::string>> pseudoPkgs;
+   std::vector<PseudoPkg> pseudoPkgs;
    // deal with the build essentials first
+   if (not AreDoingSatisfy)
    {
       std::vector<pkgSrcRecords::Parser::BuildDepRec> BuildDeps;
       for (auto && opt: _config->FindVector("APT::Build-Essential"))
@@ -678,47 +678,113 @@ bool DoBuildDep(CommandLine &CmdL)
 	 BuildDeps.push_back(rec);
       }
       std::string const pseudo = "builddeps:essentials";
-      std::string const nativeArch = _config->Find("APT::Architecture");
       WriteBuildDependencyPackage(buildDepsPkgFile, pseudo, nativeArch, BuildDeps);
-      pseudoPkgs.emplace_back(pseudo, nativeArch);
+      pseudoPkgs.emplace_back(pseudo, nativeArch, "");
+   }
+
+   if (AreDoingSatisfy)
+   {
+      std::vector<pkgSrcRecords::Parser::BuildDepRec> BuildDeps;
+      for (unsigned i = 1; i < CmdL.FileSize(); i++)
+      {
+	 const char *Start = CmdL.FileList[i];
+	 const char *Stop = Start + strlen(Start);
+	 auto Type = pkgSrcRecords::Parser::BuildDependIndep;
+
+	 // Reject '>' and '<' as operators, as they have strange meanings.
+	 bool insideVersionRestriction = false;
+	 for (auto C = Start; C + 1 != Stop; C++)
+	 {
+	    if (*C == '(')
+	       insideVersionRestriction = true;
+	    else if (*C == ')')
+	       insideVersionRestriction = false;
+	    else if (insideVersionRestriction && (*C == '<' || *C == '>'))
+	    {
+	       if (C[1] != *C && C[1] != '=')
+		  return _error->Error(_("Invalid operator '%c' at offset %d, did you mean '%c%c' or '%c='? - in: %s"), *C, (int)(C - Start), *C, *C, *C, Start);
+	       C++;
+	    }
+	 }
+
+	 if (APT::String::Startswith(Start, "Conflicts:"))
+	 {
+	    Type = pkgSrcRecords::Parser::BuildConflictIndep;
+	    Start += strlen("Conflicts:");
+	 }
+	 while (1)
+	 {
+	    pkgSrcRecords::Parser::BuildDepRec rec;
+	    Start = debListParser::ParseDepends(Start, Stop,
+						rec.Package, rec.Version, rec.Op, true, false, true, pseudoArch);
+
+	    if (Start == 0)
+	       return _error->Error("Problem parsing dependency: %s", CmdL.FileList[i]);
+	    rec.Type = Type;
+
+	    // We parsed a package that was ignored (wrong architecture restriction
+	    // or something).
+	    if (rec.Package.empty())
+	    {
+	       // If we are in an OR group, we need to set the "Or" flag of the
+	       // previous entry to our value.
+	       if (BuildDeps.empty() == false && (BuildDeps[BuildDeps.size() - 1].Op & pkgCache::Dep::Or) == pkgCache::Dep::Or)
+	       {
+		  BuildDeps[BuildDeps.size() - 1].Op &= ~pkgCache::Dep::Or;
+		  BuildDeps[BuildDeps.size() - 1].Op |= (rec.Op & pkgCache::Dep::Or);
+	       }
+	    }
+	    else
+	    {
+	       BuildDeps.emplace_back(std::move(rec));
+	    }
+
+	    if (Start == Stop)
+	       break;
+	 }
+      }
+      std::string const pseudo = "command line argument";
+      WriteBuildDependencyPackage(buildDepsPkgFile, pseudo, pseudoArch, BuildDeps);
+      pseudoPkgs.emplace_back(pseudo, pseudoArch, "");
    }
 
    // Read the source list
    if (Cache.BuildSourceList() == false)
       return false;
    pkgSourceList *List = Cache.GetSourceList();
-   std::string const pseudoArch = hostArch.empty() ? _config->Find("APT::Architecture") : hostArch;
 
-   // FIXME: Avoid volatile sources == cmdline assumption
+   if (not AreDoingSatisfy)
    {
       auto const VolatileSources = List->GetVolatileFiles();
-      if (VolatileSources.size() == VolatileCmdL.size())
+      for (auto &&pkg : VolatileCmdL)
       {
-	 for (size_t i = 0; i < VolatileSources.size(); ++i)
+	 if (unlikely(pkg.index == -1))
 	 {
-	    auto const Src = VolatileCmdL[i];
-	    if (DirectoryExists(Src))
-	       ioprintf(c1out, _("Note, using directory '%s' to get the build dependencies\n"), Src.c_str());
-	    else
-	       ioprintf(c1out, _("Note, using file '%s' to get the build dependencies\n"), Src.c_str());
-	    std::unique_ptr<pkgSrcRecords::Parser> Last(VolatileSources[i]->CreateSrcParser());
-	    if (Last == nullptr)
-	       return _error->Error(_("Unable to find a source package for %s"), Src.c_str());
-
-	    std::string const pseudo = std::string("builddeps:") + Src;
-	    WriteBuildDependencyPackage(buildDepsPkgFile, pseudo, pseudoArch,
-		  GetBuildDeps(Last.get(), Src.c_str(), StripMultiArch, hostArch));
-	    pseudoPkgs.emplace_back(pseudo, pseudoArch);
+	    _error->Error(_("Unable to find a source package for %s"), pkg.name.c_str());
+	    continue;
 	 }
+	 if (DirectoryExists(pkg.name))
+	    ioprintf(c1out, _("Note, using directory '%s' to get the build dependencies\n"), pkg.name.c_str());
+	 else
+	    ioprintf(c1out, _("Note, using file '%s' to get the build dependencies\n"), pkg.name.c_str());
+	 std::unique_ptr<pkgSrcRecords::Parser> Last(VolatileSources[pkg.index]->CreateSrcParser());
+	 if (Last == nullptr)
+	 {
+	    _error->Error(_("Unable to find a source package for %s"), pkg.name.c_str());
+	    continue;
+	 }
+
+	 auto pseudo = std::string("builddeps:") + pkg.name;
+	 WriteBuildDependencyPackage(buildDepsPkgFile, pseudo, pseudoArch,
+				     GetBuildDeps(Last.get(), pkg.name.c_str(), StripMultiArch, hostArch));
+	 pkg.name = std::move(pseudo);
+	 pseudoPkgs.push_back(std::move(pkg));
       }
-      else
-	 return _error->Error("Implementation error: Volatile sources (%lu) and"
-	       "commandline elements (%lu) do not match!", VolatileSources.size(),
-	       VolatileCmdL.size());
+      VolatileCmdL.clear();
    }
 
    bool const WantLock = _config->FindB("APT::Get::Print-URIs", false) == false;
-   if (CmdL.FileList[1] != 0)
+   if (CmdL.FileList[1] != 0 && not AreDoingSatisfy)
    {
       if (Cache.BuildCaches(WantLock) == false)
 	 return false;
@@ -736,7 +802,13 @@ bool DoBuildDep(CommandLine &CmdL)
 	 std::string const pseudo = std::string("builddeps:") + Src;
 	 WriteBuildDependencyPackage(buildDepsPkgFile, pseudo, pseudoArch,
 	       GetBuildDeps(Last, Src.c_str(), StripMultiArch, hostArch));
-	 pseudoPkgs.emplace_back(pseudo, pseudoArch);
+	 std::string reltag = *I;
+	 size_t found = reltag.find_last_of("/");
+	 if (found == std::string::npos)
+	    reltag.clear();
+	 else
+	    reltag.erase(0, found + 1);
+	 pseudoPkgs.emplace_back(pseudo, pseudoArch, std::move(reltag));
       }
    }
 
@@ -750,12 +822,24 @@ bool DoBuildDep(CommandLine &CmdL)
    {
       pkgDepCache::ActionGroup group(Cache);
       TryToInstall InstallAction(Cache, &Fix, false);
+      std::list<std::pair<pkgCache::VerIterator, std::string>> candSwitch;
       for (auto const &pkg: pseudoPkgs)
       {
-	 pkgCache::PkgIterator const Pkg = Cache->FindPkg(pkg.first, pkg.second);
+	 pkgCache::PkgIterator const Pkg = Cache->FindPkg(pkg.name, pkg.arch);
+	 if (Pkg.end())
+	    continue;
+	 if (pkg.release.empty())
+	    Cache->SetCandidateVersion(Pkg.VersionList());
+	 else
+	    candSwitch.emplace_back(Pkg.VersionList(), pkg.release);
+      }
+      if (candSwitch.empty() == false)
+	 InstallAction.propergateReleaseCandiateSwitching(candSwitch, c0out);
+      for (auto const &pkg: pseudoPkgs)
+      {
+	 pkgCache::PkgIterator const Pkg = Cache->FindPkg(pkg.name, pkg.arch);
 	 if (Pkg.end())
 	    continue;
-	 Cache->SetCandidateVersion(Pkg.VersionList());
 	 InstallAction(Cache[Pkg].CandidateVerIter(Cache));
 	 removeAgain.push_back(Pkg);
       }
@@ -773,7 +857,7 @@ bool DoBuildDep(CommandLine &CmdL)
 
    {
       pkgDepCache::ActionGroup group(Cache);
-      if (_config->FindB("APT::Get::Build-Dep-Automatic", false) == false)
+      if (_config->FindB(AreDoingSatisfy ? "APT::Get::Satisfy-Automatic" : "APT::Get::Build-Dep-Automatic", false) == false)
       {
 	 for (auto const &pkg: removeAgain)
 	 {
