@@ -49,7 +49,6 @@
 #include <apt-pkg/pkgsystem.h>
 #include <apt-pkg/progress.h>
 #include <apt-pkg/sourcelist.h>
-#include <apt-pkg/sptr.h>
 #include <apt-pkg/srcrecords.h>
 #include <apt-pkg/strutl.h>
 #include <apt-pkg/upgrade.h>
@@ -417,6 +416,7 @@ static std::vector<aptDispatchWithHelp> GetCommands()			/*{{{*/
       {"full-upgrade", &DoDistUpgrade, nullptr},
       {"dselect-upgrade", &DoDSelectUpgrade, _("Follow dselect selections")},
       {"build-dep", &DoBuildDep, _("Configure build-dependencies for source packages")},
+      {"satisfy", &DoBuildDep, _("Satisfy dependency strings")},
       {"clean", &DoClean, _("Erase downloaded archive files")},
       {"autoclean", &DoAutoClean, _("Erase old downloaded archive files")},
       {"auto-clean", &DoAutoClean, nullptr},
