@@ -43,7 +43,7 @@ class FileMethod : public aptMethod
 /* */
 bool FileMethod::Fetch(FetchItem *Itm)
 {
-   URI Get = Itm->Uri;
+   URI Get(Itm->Uri);
    std::string File = Get.Path;
    FetchResult Res;
    if (Get.Host.empty() == false)
